@@ -28,7 +28,7 @@ from nylas.client.restful_models import (
     Draft,
 )
 from nylas.client.neural_api_models import Neural
-from nylas.utils import convert_datetimes_to_timestamps, timestamp_from_dt
+from nylas.utils import timestamp_from_dt, create_request_body
 
 DEBUG = environ.get("NYLAS_CLIENT_DEBUG")
 API_SERVER = "https://api.nylas.com"
@@ -360,10 +360,8 @@ class APIClient(json.JSONEncoder):
                 self.api_server, self.client_id, cls.collection_name, postfix
             )
 
-        converted_filters = convert_datetimes_to_timestamps(
-            filters, cls.datetime_filter_attrs
-        )
-        url = str(URLObject(url).add_query_params(converted_filters.items()))
+        converted_data = create_request_body(filters, cls.datetime_filter_attrs)
+        url = str(URLObject(url).add_query_params(converted_data.items()))
         response = self._get_http_session(cls.api_root).get(url)
         results = _validate(response).json()
         return [cls.create(self, **x) for x in results if x is not None]
@@ -383,10 +381,8 @@ class APIClient(json.JSONEncoder):
                 self.api_server, self.client_id, cls.collection_name, id, postfix
             )
 
-        converted_filters = convert_datetimes_to_timestamps(
-            filters, cls.datetime_filter_attrs
-        )
-        url = str(URLObject(url).add_query_params(converted_filters.items()))
+        converted_data = create_request_body(filters, cls.datetime_filter_attrs)
+        url = str(URLObject(url).add_query_params(converted_data.items()))
         response = self._get_http_session(cls.api_root).get(
             url, headers=headers, stream=stream
         )
@@ -417,7 +413,7 @@ class APIClient(json.JSONEncoder):
         if cls == File:
             response = session.post(url, files=data)
         else:
-            converted_data = convert_datetimes_to_timestamps(data, cls.datetime_attrs)
+            converted_data = create_request_body(data, cls.datetime_attrs)
             headers = {"Content-Type": "application/json"}
             headers.update(self.session.headers)
             response = session.post(url, json=converted_data, headers=headers)
@@ -437,8 +433,7 @@ class APIClient(json.JSONEncoder):
             response = session.post(url, files=data)
         else:
             converted_data = [
-                convert_datetimes_to_timestamps(datum, cls.datetime_attrs)
-                for datum in data
+                create_request_body(datum, cls.datetime_attrs) for datum in data
             ]
             headers = {"Content-Type": "application/json"}
             headers.update(self.session.headers)
@@ -468,7 +463,7 @@ class APIClient(json.JSONEncoder):
 
         session = self._get_http_session(cls.api_root)
 
-        converted_data = convert_datetimes_to_timestamps(data, cls.datetime_attrs)
+        converted_data = create_request_body(data, cls.datetime_attrs)
         response = session.put(url, json=converted_data)
 
         result = _validate(response).json()
@@ -492,7 +487,7 @@ class APIClient(json.JSONEncoder):
             )
 
         url = URLObject(self.api_server).with_path(url_path)
-        converted_data = convert_datetimes_to_timestamps(data, cls.datetime_attrs)
+        converted_data = create_request_body(data, cls.datetime_attrs)
 
         session = self._get_http_session(cls.api_root)
         response = session.post(url, json=converted_data)
@@ -507,7 +502,7 @@ class APIClient(json.JSONEncoder):
 
         session = self._get_http_session(cls.api_root)
 
-        converted_data = convert_datetimes_to_timestamps(data, cls.datetime_attrs)
+        converted_data = create_request_body(data, cls.datetime_attrs)
         response = session.request(method, url, json=converted_data)
 
         result = _validate(response).json()
